pub struct Query { /* private fields */ }Expand description
Query object
Implementations
Sourceimpl Query
impl Query
Sourcepub fn with_params(self, params: HashMap<String, Value>) -> Self
pub fn with_params(self, params: HashMap<String, Value>) -> Self
Set query parameters
parameters is data, sent to YDB in binary form
Example with macros:
let query = Query::new("
SELECT $val AS res
").with_params(ydb_params!("$val" => 123 as i64));Example full:
let mut params: HashMap::<String,Value> = HashMap::new();
params.insert("$val".to_string(), Value::from(123 as i64));
let query = Query::new("
SELECT $val AS res
").with_params(params);Sourcepub fn with_keep_in_cache(self, val: bool) -> Self
pub fn with_keep_in_cache(self, val: bool) -> Self
Set force keep in cache flag for query. By default flag is true for query with non empty params and false for query without params.
Example:
// force use server cache for the query
let q = Query::new("SELECT 1").with_keep_in_cache(true);
// force disable server cache for the query
let q = Query::new("SELECT $res AS res")
.with_params(ydb_params!("$val" => 123 as i64))
.with_keep_in_cache(false);Trait Implementations