pub struct TopicReader { /* private fields */ }Implementations
Sourceimpl TopicReader
impl TopicReader
pub async fn read_batch(&mut self) -> YdbResult<TopicReaderBatch>
Sourcepub async fn pop_batch_in_tx(
&mut self,
tx: &mut Box<dyn Transaction>,
) -> YdbResult<TopicReaderBatch>
pub async fn pop_batch_in_tx( &mut self, tx: &mut Box<dyn Transaction>, ) -> YdbResult<TopicReaderBatch>
Read a batch of messages within a transaction context.
The TopicReaderBatch from the result will be committed within the tx transaction.
This is an EXAMPLE of the interface. IT IS NOT PRODUCTION READY.
The reader will fail consistently on ANY error, including TLI.
You can use this method to test the interface and try writing your own code to see how it works. DO NOT USE IN PRODUCTION
pub fn commit( &mut self, commit_marker: TopicReaderCommitMarker, ) -> YdbResult<()>